---
title: <span class="badge object-type-scalar"></span> GibibitsPerSecond
---
# <span class="badge object-type-scalar"></span> GibibitsPerSecond

Data rate: gibibits/sec

## Definition

```python
# Data rate: gibibits/sec
GibibitsPerSecond: typing.Literal["Gibits"] = "Gibits"
```
